==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebColumnToggledEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDetailDescription } from "./WebColumnToggledEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnToggledEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnToggledEventArgsDetailDescriptionMetadata, _super);
    function WebColumnToggledEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnToggledEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnToggledEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnToggledEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnToggledEventArgsDetailDescriptionMetadata.c(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebColumnToggledEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnToggledEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnToggledEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("Checked", "Boolean");
    };
    WebColumnToggledEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnToggledEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebColumnToggledEventArgsDetail", function () { return new WebColumnToggledEventArgsDetailDescription(); });
        a.z("WebColumnToggledEventArgsDetail", WebColumnToggledEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnToggledEventArgsDetailDescriptionMetadata.$t = markType(WebColumnToggledEventArgsDetailDescriptionMetadata, 'WebColumnToggledEventArgsDetailDescriptionMetadata');
    WebColumnToggledEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnToggledEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnToggledEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDetailDescription } from "./WebColumnToggledEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnToggledEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnToggledEventArgsDetailDescriptionMetadata, _super);
    function WebColumnToggledEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnToggledEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnToggledEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnToggledEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnToggledEventArgsDetailDescriptionMetadata.c(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnToggledEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnToggledEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnToggledEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Column", "ExportedType:WebColumn");
        a.item("Checked", "Boolean");
    };
    WebColumnToggledEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnToggledEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebColumnToggledEventArgsDetail", function () { return new WebColumnToggledEventArgsDetailDescription(); });
        a.ab("WebColumnToggledEventArgsDetail", WebColumnToggledEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnToggledEventArgsDetailDescriptionMetadata.$t = markType(WebColumnToggledEventArgsDetailDescriptionMetadata, 'WebColumnToggledEventArgsDetailDescriptionMetadata');
    WebColumnToggledEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnToggledEventArgsDetailDescriptionMetadata };
